PushFireException class abstract

Base exception class for PushFire SDK

Implemented types
Implementers

Constructors

PushFireException(String message, {String? code, dynamic originalError})
const

Properties

code String?
Optional error code
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message
final
originalError → dynamic
Optional underlying error
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited