Subscriber class
Represents a subscriber in the PushFire system
Constructors
Properties
- deviceId → String?
-
Device ID associated with this subscriber
final
- email → String?
-
Subscriber email
final
- externalId → String
-
External ID from your system
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
Unique subscriber identifier
final
-
metadata
→ Map<
String, dynamic> ? -
Additional metadata as key-value pairs
final
- name → String?
-
Subscriber name
final
- phone → String?
-
Subscriber phone number
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? id, String? deviceId, String? externalId, String? name, String? email, String? phone, Map< String, dynamic> ? metadata}) → Subscriber - Create a copy of this subscriber with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert Subscriber to JSON
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override