SubscriberTag class
Represents a tag associated with a subscriber
Constructors
- SubscriberTag({required String tagId, required String subscriberId, required String value})
-
const
-
SubscriberTag.fromJson(Map<
String, dynamic> json) -
Create a SubscriberTag from JSON
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriberId → String
-
Subscriber identifier
final
- tagId → String
-
Unique tag identifier
final
- value → String
-
Tag value
final
Methods
-
copyWith(
{String? tagId, String? subscriberId, String? value}) → SubscriberTag - Create a copy of this tag with updated values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert SubscriberTag to JSON
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override